"""
Octopoda — Memory engine for AI agents.

This package re-exports everything from synrix so both import styles work:
    from octopoda import Octopoda
    from synrix import Octopoda
"""
from synrix import *  # noqa: F401,F403
from synrix import (
    Octopoda,
    Memory,
    Agent,
    SynrixClient,
    SynrixSQLiteClient,
    SynrixAgentBackend,
    SynrixError,
    OctopodaError,
    AuthError,
    RateLimitError,
    SynrixConnectionError,
    SynrixNotFoundError,
    __version__,
)

__all__ = [
    "Octopoda",
    "Memory",
    "Agent",
    "SynrixClient",
    "SynrixSQLiteClient",
    "SynrixAgentBackend",
    "SynrixError",
    "OctopodaError",
    "AuthError",
    "RateLimitError",
    "SynrixConnectionError",
    "SynrixNotFoundError",
]
